PWI Demo 5 - Picassa Webalbum Integrator (PWI)

### PWI Demo

Sample code:

    		    $(document).ready(function() {
    		        $("#container").pwi({
    		            username: 'jquery.pwi',
    		            mode: 'albums',
    		            albums: ["Album1","Album2"],
    		            thumbCss: { margin: '5px' },
    		            onclickThumb: ""
    		        });

    		    });

Demo's:

demo 1 - Simple and all default
demo 2 - Single album
demo 3 - Latest additions!
demo 4 - Unlisted album!
demo 5 - Selective albums
demo 6 - Simple with FancyBox
demo 7 - Multiple galleries AND FancyBox
demo 8 - Override onclickAlbumThumb
demo 9 - Photo's by Keyword/tag
demo 10 - Photo's by Keyword/tag from single album
demo 11 - Simple album list without thumbs

Things you can overrule, specifified values are the defaults, only username is mandatory:

            username: '', //-- Must be explicitly set!!!

            mode: 'albums', //-- can be: album, albums, latest (keyword = obsolete but backwards compatible, now just fill in a keyword in the settings to enable keyword-photos)

            album: "", //-- For loading a single album

            authKey: "", //-- for loading a single album that is private (use in 'album' mode only)

            albums: [], //-- use to load specific albums only: ["MyAlbum", "TheSecondAlbumName", "OtherAlbum"]

            albumCrop: 1, //-- crop thumbs on albumpage to have all albums in square thumbs (see albumThumbSize for supported sizes)

            albumTitle: "", //-- overrule album title in 'album' mode

            albumThumbSize: 160, //-- specify thumbnail size of albumthumbs (default: 72, cropped not supported, supported cropped/uncropped: 32, 48, 64, 160 and uncropped only: 72, 144, 200, 288, 320, 400, 512, 576, 640, 720, 800)

            albumMaxResults: 999, //-- load only the first X albums

            albumsPerPage: 999, //-- show X albums per page (activates paging on albums when this amount is less then the available albums)

            albumPage: 1, //-- force load on specific album

            albumTypes: "public", //-- load public albums, not used for now

            page: 1, //-- initial page for an photo page

            photoSize: 800, //-- size of large photo loaded in slimbox, fancybox or other

            maxResults: 50, //-- photos per page

            showPager: 'bottom', //'top', 'bottom', 'both' (for both albums and album paging)

            thumbSize: 72,  //-- specify thumbnail size of photos (default: 72, cropped not supported, supported cropped/uncropped: 32, 48, 64, 160 and uncropped only: 72, 144, 200, 288, 320, 400, 512, 576, 640, 720, 800)

            thumbCrop: 0, //-- force crop on photo thumbnails (see thumbSize for supported sized)

            thumbCss: {

                'margin': '5px'

            },

            onclickThumb: "", //-- overload the function when clicked on a photo thumbnail

            onclickAlbumThumb: "", //-- overload the function when clicked on a album thumbnail

            popupExt: "", //-- extend the photos by connecting them to for example Fancybox (see demos for example)

            showAlbumTitles: true,  //--following settings should be self-explanatory

            showAlbumThumbs: true,

            showAlbumdate: true,

            showAlbumPhotoCount: true,

            showAlbumDescription: true,

            showAlbumLocation: true,

            showSlideshowLink: true,

            showPhotoCaption: false,

            showPhotoCaptionDate: false,

            showCaptionLength: 9999,

            showPhotoDownload: false,

            showPhotoDate: true,

            labels: {

                photo: "photo",

                photos: "photos",

                albums: "Back to albums",

                slideshow: "Display slideshow",

                loading: "PWI fetching data...",

                page: "Page",

                prev: "Previous",

                next: "Next",

                devider: "|"

            }, //-- translate if needed

            months: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],

            slimbox_config: {

                loop: false,

                overlayOpacity: 0.6,

                overlayFadeDuration: 400,

                resizeDuration: 400,

                resizeEasing: "swing",

                initialWidth: 250,

                initlaHeight: 250,

                imageFadeDuration: 400,

                captionAnimationDuration: 400,

                counterText: "{x}/{y}",

                closeKeys: [27, 88, 67, 70],

                prevKeys: [37, 80],

                nextKeys: [39, 83]

            }, //-- overrule defaults is needed

            blockUIConfig: {

                message: "loading...",

                css: "pwi_loader"

            }